Energyml types
==============

[![License](https://img.shields.io/pypi/l/resqml22py)](https://github.com/geosiris-technologies/energyml-python-generator/blob/main/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/energyml-python-generator/badge/?version=latest)](https://energyml-python-generator.readthedocs.io/en/latest/?badge=latest)
![Python version](https://img.shields.io/pypi/pyversions/resqml22py)
![Status](https://img.shields.io/pypi/status/resqml22py)




Installation
------------

Energyml-types can be installed with pip : 

```console
pip install resqml22
```

or with poetry: 
```console
poetry add resqml22
```
